@@ -1,6 +1,6 @@
 import logging
 
-import pkg_resources
+import pkg_resources  # type: ignore
 
 from . import io, log
 from .aggregate import aggregate, aggregate_async
@@ -26,6 +26,7 @@ from .utils import (
 )
 from .worker_pool.pool import WorkerPool
 
+
 plugins = {
     entry_point.name: entry_point.load()
     for entry_point
