@@ -183,7 +183,8 @@ class ThreadPoolExecutor(ThreadPoolExecutorBase):
 
             return future
 
-    def shutdown(self, wait: bool = True) -> None:
+    # noinspection PyMethodOverriding
+    def shutdown(self, wait: bool = True) -> None:  # type: ignore
         for _ in self.__pool:
             self.__tasks.put_nowait(None)
 
@@ -226,7 +227,7 @@ async def _awaiter(future: Future) -> T:
         raise
 
 
-def threaded(func: F) -> Callable[..., typing.Awaitable[Any]]:
+def threaded(func: Callable[..., T]) -> Callable[..., typing.Awaitable[T]]:
     if asyncio.iscoroutinefunction(func):
         raise TypeError("Can not wrap coroutine")
 
@@ -246,7 +247,7 @@ def run_in_new_thread(
     func: F,
     args: Any = (),
     kwargs: Any = MappingProxyType({}),
-    detouch: bool = True,
+    detach: bool = True,
     no_return: bool = False,
 ) -> asyncio.Future:
     loop = asyncio.get_event_loop()
@@ -287,7 +288,7 @@ def run_in_new_thread(
         ),
     )
 
-    thread.daemon = detouch
+    thread.daemon = detach
 
     thread.start()
     return future
@@ -295,10 +296,10 @@ def run_in_new_thread(
 
 def threaded_separate(
     func: F,
-    detouch: bool = True,
+    detach: bool = True,
 ) -> Callable[..., typing.Awaitable[Any]]:
     if isinstance(func, bool):
-        return partial(threaded_separate, detouch=detouch)
+        return partial(threaded_separate, detach=detach)
 
     if asyncio.iscoroutinefunction(func):
         raise TypeError("Can not wrap coroutine")
@@ -306,7 +307,7 @@ def threaded_separate(
     @wraps(func)
     def wrap(*args: Any, **kwargs: Any) -> Any:
         future = run_in_new_thread(
-            func, args=args, kwargs=kwargs, detouch=detouch,
+            func, args=args, kwargs=kwargs, detach=detach,
         )
 
         return _awaiter(future)
